@@ -31,6 +31,6 @@ function route_redirect()
 {
 	$uri = $_SERVER['REQUEST_URI'];
 	$uri_parts = explode('?', $uri);
-	$url = str_replace('nagiosxi', 'nagvis', get_base_url()) . 'frontend/nagvis-js/index.php?' . $uri_parts[1];
+	$url = preg_replace('~(^https?://[^/]+)/nagiosxi~', '$1/nagvis', get_base_url(), 1) . 'frontend/nagvis-js/index.php?' . $uri_parts[1];
 	header("Location: " . $url);
 }
