@@ -62,12 +62,12 @@ function display_nna_queries()
     $excluders = grab_request_var("excluders", array());
     $manual_run = grab_request_var("manual_run", 0);
 
-    // make sure we have enough elements for the explode
-    while (substr_count($server, "|") < 5) {
-        $server .= "|";
-    }
-
-    list($address, $secure, $api_key, $allow_invalid_ssl, $look_back_hours) = explode("|", $server);
+    $server_data = json_decode($server, true);
+    $address = $server_data['address'] ?? '';
+    $secure = $server_data['secure'] ?? 0;
+    $api_key = $server_data['api_key'] ?? '';
+    $look_back_hours = $server_data['look_back_hours'] ?? 4;
+    $allow_invalid_ssl = $server_data['allow_invalid_ssl'] ?? 0;
 
     if (empty($allow_invalid_ssl)) {
         $allow_invalid_ssl = false;
@@ -130,7 +130,7 @@ function display_nna_queries()
         ?>
 
         <script type="text/javascript">
-            var nna_server = "<?php echo $server; ?>";
+            var nna_server = "<?php json_encode($server); ?>";
             var query_id = <?php echo $qid; ?>;
             var object_type = "<?php echo $object_type; ?>";
             var object = <?php if (empty($object)) { echo '""'; } else { echo $object; } ?>;
@@ -188,16 +188,16 @@ function display_nna_queries()
 
                 $('#object').change(function () {
                     var obj = $(this).find("option:selected");
-                    var server = $('#nna_server').val().split("|");
-                    var api_url = get_nna_api_url(server[0], server[1]);
-                    load_sources_views(api_url, server[2], obj.val());
+                    var server = $('#nna_server').val();
+                    server = JSON.parse(server);
+                    var api_url = get_nna_api_url(server['address'], server['secure']);
+                    load_sources_views(api_url, server['api_key'], obj.val());
                     $('#object_name').val(obj.text());
                 });
 
             });
 
             function load_queries_from_server(server) {
-                var server = server.split("|");
                 $('#error').hide();
 
                 $.post('<?php get_base_url();?> /nagiosxi/includes/components/nagiosna/nna-ajaxhelper.php', {
@@ -230,13 +230,13 @@ function display_nna_queries()
             }
 
             function load_sources_from_server(server) {
-                var server = server.split("|");
-                var api_url = get_nna_api_url(server[0], server[1]);
+                var server = JSON.parse(server);
+                var api_url = get_nna_api_url(server['address'], server['secure']);
 
                 $.post('<?php get_base_url();?> /nagiosxi/includes/components/nagiosna/nna-ajaxhelper.php', {
                     cmd: 'get_query_data',
                     nsp: '<?php echo get_nagios_session_protector_id(); ?>',
-                    server: server,
+                    server: JSON.stringify(server),
                     endpoint: 'sources/read',
                     ssl: '<?php echo $allow_invalid_ssl?>'
                 }, function() {}, "json")
@@ -257,14 +257,12 @@ function display_nna_queries()
                     $('#object_name').val($('#object option:selected').text());
 
                     // Grab the source and create a "Use View checkbox if it has any associated views"
-                    load_sources_views(api_url, server[2], selected_id);
+                    load_sources_views(api_url, server["api_key"], selected_id);
 
                 }, 'json');
             }
 
             function load_sourcegroups_from_server(server) {
-                var server = server.split("|");
-
                 $.post('<?php get_base_url();?> /nagiosxi/includes/components/nagiosna/nna-ajaxhelper.php', {
                     cmd: 'get_query_data',
                     nsp: '<?php echo get_nagios_session_protector_id(); ?>',
