@@ -171,7 +171,17 @@ function fetch_timeline($args)
         sourceHeight: $('#{$args['container']}').height(),
         sourceWidth: $('#{$args['container']}').width(),
         filename: '{$filename}',
-        chartOptions: { chart: { spacing: [25, 25, 25, 20], marginRight: 40 } },
+        chartOptions: {
+            chart: {
+                spacing: [25, 25, 25, 20],
+                marginRight: 40
+            },
+            legend: {
+                itemStyle: {
+                    'font-size': '10px',
+                }
+            }
+        },
         host: '{$args['host']}',
         service: '{$args['service']}',
         start: {$rrd_start},
@@ -276,7 +286,8 @@ function fetch_timeline($args)
                 },
                 yAxis: {
                     title: {
-                        text: UOM  // unit of measurement from perf data
+                        text: UOM,  // unit of measurement from perf data
+                        margin: 25
                     },
                     labels: {
                         formatter: function() {
