@@ -1332,7 +1332,7 @@ logf=""
 #
 #
 ############## Component Logs 
-COMPLOGS="auditlog.log capacityplanning.log scheduledbackups.log"
+COMPLOGS="auditlog.log capacityplanning.log scheduledbackups.log sso-integration.log"
 LINECOUNT="4000"
 ###############
 #
