@@ -463,7 +463,7 @@ function noc_service_row(&$table, $host)
         if (is_neptune()) {
             $table .=
             "<tr class='servicerow'>
-            <td  class='host_name table-host-width'><a href='../xicore/status.php?show=hostdetail&host={$host->host_name}'><span class='status-dot dot-10 " . host_class("$host->host_current_state") . "'></span>*{$host->host_name}</a> <div class='hosticons'>" . $host_graph_icon . "</div></td>
+            <td  class='host_name table-host-width'><a href='../xicore/status.php?show=hostdetail&host={$host->host_name}'><span class='status-dot dot-10 " . host_class("$host->host_current_state") . "'></span>{$host->host_name}</a> <div class='hosticons'>" . $host_graph_icon . "</div></td>
             <td  class='description table-service-width'><a href='../xicore/status.php?show=servicedetail&host={$host->host_name}&service={$host->name}'><span class='status-dot dot-10 " . service_class("$host->current_state") . "'></span>{$host->name}</a> <div class='hosticons'>" . $graph_icon . "</div></td>
             <td><div class='duration'>{$stateduration}</div></td>
             <td class='statustext'>{$status_info}</td>
@@ -471,7 +471,7 @@ function noc_service_row(&$table, $host)
         } else {
             $table .=
             "<tr class='servicerow'>
-            <td class='host_name " . host_class("$host->host_current_state") . "'><a style='color:black' href='../xicore/status.php?show=hostdetail&host={$host->host_name}'>*{$host->host_name}</a> <div class='hosticons'>" . $host_graph_icon . "</div></td>
+            <td class='host_name " . host_class("$host->host_current_state") . "'><a style='color:black' href='../xicore/status.php?show=hostdetail&host={$host->host_name}'>{$host->host_name}</a> <div class='hosticons'>" . $host_graph_icon . "</div></td>
             <td class='description " . service_class("$host->current_state") . "'><a style='color:black' href='../xicore/status.php?show=servicedetail&host={$host->host_name}&service={$host->name}'>{$host->name}</a> <div class='hosticons'>" . $graph_icon . "</div></td>
             <td><div class='duration'>{$stateduration}</div></td>
             <td class='statustext'>{$status_info}</td>
